==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/th_TH.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "กิจกรรม",
    "Personal activity feed for %s" : "ฟีดกิจกรรมส่วนตัวสำหรับ %s",
    "Your feed URL is invalid" : "ฟีด URL ของคุณไม่ถูกต้อง",
    "Your settings have been updated." : "การตั้งค่าของคุณได้รับการปรับปรุง",
    "This stream will show events like additions, changes & shares" : "สตรีมนี้จะแสดงเหตุการณ์เพิ่มเติม เช่นการเปลี่ยนแปลงและการแชร์",
    "There are no events for this filter" : "ไม่มีกิจกรรมสำหรับตัวกรองนี้",
    "Activity notification" : "การแจ้งเตือนกิจกรรม",
    "All Activities" : "กิจกรรมทั้งหมด",
    "Activities by you" : "กิจกรรมของคุณ",
    "Activities by others" : "กิจกรรมของคนอื่นๆ",
    "\"remote user\"" : "\"ผู้ใช้ระยะไกล\"",
    "in %s" : "ใน %s",
    "%s and %s" : "%s และ %s",
    ", " : "หรือ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s และ <strong class=\"tooltip\" title=\"%s\">%n ฯลฯ</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s และ %n ฯลฯ"],
    "Hello %s," : "สวัสดี %s",
    "You are receiving this email because in the last hour the following things happened at %s" : "คุณได้รับอีเมลนี้เนื่องจากในชั่วโมงที่ผ่านมามีบางอย่างเกิดขึ้นที่ %s",
    "You are receiving this email because in the last day the following things happened at %s" : "คุณได้รับอีเมลนี้เนื่องจากในหนึ่งวันที่ผ่านมามีบางอย่างเกิดขึ้นที่ %s",
    "You are receiving this email because in the last week the following things happened at %s" : "คุณได้รับอีเมลนี้เนื่องจากในสัปดาห์ที่ผ่านมามีบางอย่างเกิดขึ้นที่ %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* และ %n ฯลฯ"],
    "Notifications" : "การแจ้งเตือน",
    "Mail" : "จดหมาย",
    "Stream" : "สตรีม",
    "List your own actions in the stream" : "รายการสิ่งที่คุณทำในสตรีม",
    "Notify about your own actions via email" : "แจ้งเตือนเกี่ยวกับสิ่งที่คุณทำผ่านทางอีเมล",
    "You need to set up your email address before you can receive notification emails." : "คุณจะได้รับอีเมลแจ้งเตือนหลังจากที่คุณตั้งค่าที่อยู่อีเมลของคุณ",
    "Send emails:" : "ส่งอีเมล:",
    "Hourly" : "รายชั่วโมง",
    "Daily" : "รายวัน",
    "Weekly" : "รายสัปดาห์",
    "Activity feed" : "ฟีดกิจกรรม",
    "Enable RSS feed" : "เปิดใช้งานฟีด RSS",
    "No activity yet" : "ยังไม่มีกิจกรรม",
    "No more events to load" : "ไม่มีการโหลดกิจกรรมเพิ่มเติม",
    "Files" : "ไฟล์"
},
"nplurals=1; plural=0;");

==> owncloud-8.2.2p3.tgz: owncloud/apps/activity/l10n/th_TH.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "กิจกรรม",
    "Personal activity feed for %s" : "ฟีดกิจกรรมส่วนตัวสำหรับ %s",
    "Your feed URL is invalid" : "ฟีด URL ของคุณไม่ถูกต้อง",
    "Your settings have been updated." : "การตั้งค่าของคุณได้รับการปรับปรุง",
    "Mail" : "จดหมาย",
    "Stream" : "สตรีม",
    "Activities" : "กิจกรร",
    "Error loading activities" : "เกิดข้อผิดพลาดขณะโหลดกิจกรรม",
    "No activities" : "ไม่มีกิจกรรม",
    "This stream will show events like additions, changes & shares" : "สตรีมนี้จะแสดงเหตุการณ์เพิ่มเติม เช่นการเปลี่ยนแปลงและการแชร์",
    "There are no events for this filter" : "ไม่มีกิจกรรมสำหรับตัวกรองนี้",
    "Activity notification" : "การแจ้งเตือนกิจกรรม",
    "All Activities" : "กิจกรรมทั้งหมด",
    "Activities by you" : "กิจกรรมของคุณ",
    "Activities by others" : "กิจกรรมของคนอื่นๆ",
    "\"remote user\"" : "\"ผู้ใช้ระยะไกล\"",
    "in %s" : "ใน %s",
    "%s and %s" : "%s และ %s",
    ", " : "หรือ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s และ <strong %s>อื่นๆอีก %n</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s และ %n ฯลฯ"],
    "Hello %s," : "สวัสดี %s",
    "You are receiving this email because the following things happened at %s" : "หากคุณได้รับอีเมลนี้เป็นเพราะว่ามีบางอย่างผิดปกติที่ %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* และ %n ฯลฯ"],
    "Notifications" : "การแจ้งเตือน",
    "List your own actions in the stream" : "รายการสิ่งที่คุณทำในสตรีม",
    "Notify about your own actions via email" : "แจ้งเตือนเกี่ยวกับสิ่งที่คุณทำผ่านทางอีเมล",
    "You need to set up your email address before you can receive notification emails." : "คุณจะได้รับอีเมลแจ้งเตือนหลังจากที่คุณตั้งค่าที่อยู่อีเมลของคุณ",
    "Send emails:" : "ส่งอีเมล:",
    "Hourly" : "รายชั่วโมง",
    "Daily" : "รายวัน",
    "Weekly" : "รายสัปดาห์",
    "Activity feed" : "ฟีดกิจกรรม",
    "Enable RSS feed" : "เปิดใช้งานฟีด RSS",
    "No activity yet" : "ยังไม่มีกิจกรรม",
    "No more events to load" : "ไม่มีการโหลดกิจกรรมเพิ่มเติม",
    "Files" : "ไฟล์",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s และ <strong class=\"has-tooltip\" title=\"%s\">อื่นๆอีก %n</strong>"]
},
"nplurals=1; plural=0;");
